<?php
namespace PhotoPrismUpload\Entities;

use PhotoPrismUpload\API\LoggerFactory;

/** A PhotoPrism Photo */
class Photo
{

    /** @var string $thumbnail_token Token for fetching the thumbnail*/
    public string $thumbnail_token = '';

    /** @var string $uid Unique Id of the photo */
    public string $uid = '';

    /** @var string $id Id of the photo */
    public int $id = 0;

    /** @var string $type Type of the photo (image, video, etc) */
    public string $type = '';

    public string $fileUID;
    public string $fileRoot;
    public string $fileName;
    public string $hash;
    public int $width;
    public int $height;

    public array $files;

    /**
     * Creates a new photo from the api response
     *
     * @param array $response Photoprism API response containing a photo object
     *
     * @return void
     */
    public function __construct(
        array $response
    ) {
        $this->uid = $response['UID'];
        $this->id = intval($response['ID']);
        $this->type = $response['Type'];
        $this->fileUID = $response['FileUID'];
        $this->fileRoot = $response['FileRoot'];
        $this->fileName = $response['FileName'];
        $this->hash = $response['Hash'];
        $this->width = intval($response['Width']);
        $this->height = intval($response['Height']);
        $this->logger = LoggerFactory::create('PhotoPrismUpload.Photo');
    }

    /**
     * Gets the thumbnail URL path for this image.
     * Starts with a leading /
     *
     * @return string
     */
    public function getThumbnailUrl(string $size = 'tile_500'): string
    {
        return "/t/{$this->hash}/{$this->thumbnail_token}/{$size}";
    }
}
